@@ -7,6 +7,10 @@ def is_naive(dt):
     """ Determines if a given datetime.datetime is naive. """
     return dt.tzinfo is None or dt.tzinfo.utcoffset(dt) is None
 
+def total_seconds(delta):
+    """ Determines total seconds with python < 2.7 compat """
+    # http://stackoverflow.com/questions/3694835/python-2-6-5-divide-timedelta-with-timedelta
+    return (delta.microseconds + (delta.seconds + delta.days * 24 * 3600) * 1e6) / 1e6
 
 def guess_timezone(dt):
     """ Attempts to convert a naive datetime to an aware datetime """
@@ -15,7 +19,7 @@ def guess_timezone(dt):
         # case, and then defaults to utc
 
         delta = datetime.now() - dt
-        if delta.total_seconds() < 5:
+        if total_seconds(delta) < 5:
             # this was created using datetime.datetime.now()
             # so we are in the local timezone
             return dt.replace(tzinfo=tzlocal())
